#
# spec file for package below
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           below
Version:        0.9.0~0
Release:        2.1
Summary:        A time traveling resource monitor for modern Linux systems
License:        Apache-2.0
URL:            https://github.com/facebookincubator/below
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Patch0:         001-harden-systemd-unit.patch
BuildRequires:  cargo-packaging
BuildRequires:  clang-devel
BuildRequires:  libelf-devel
BuildRequires:  systemd-rpm-macros
Recommends:     logrotate
ExclusiveArch:  %{rust_tier1_arches}

%description
below is an interactive tool to view and record historical system data. It has support for:

- information regarding hardware resource utilization
- viewing the cgroup hierarchy
- cgroup and process information
- pressure stall information (PSI)
- record mode to record system data
- replay mode to replay historical system data
- live mode to view live system data
- dump subcommand to report script-friendly information (e.g. JSON and CSV)

below does not have support for cgroup1.

%pre
%service_add_pre %{name}.service

%post
%service_add_post %{name}.service

%preun
%service_del_preun %{name}.service

%postun
%service_del_postun %{name}.service

%prep
%autosetup -p1 -a1

%build
%{cargo_build}

%check

%install
install -D -m0644 %{_builddir}/%{name}-%{version}%{_sysconfdir}/%{name}.service %{buildroot}%{_unitdir}/%{name}.service
install -D -p -m0644 %{_builddir}/%{name}-%{version}%{_sysconfdir}/logrotate.conf %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -D -d -m0755 %{buildroot}%{_bindir}
install -m0755 %{_builddir}/%{name}-%{version}/target/release/%{name} %{buildroot}%{_bindir}/%{name}
install -d -m1755 %{buildroot}%{_localstatedir}/log/%{name}

%files
%license LICENSE
%{_bindir}/%{name}
%{_unitdir}/%{name}.service
%dir %{_sysconfdir}/logrotate.d
%dir %{_localstatedir}/log/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}

%changelog
* Sat Mar  8 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- Apply hardening to the systemd service
  * Add 001-harden-systemd-unit.patch
* Wed Feb 26 2025 Alessio Biancalana <dottorblaster@opensuse.org>
- Update to version 0.9.0~0:
  * Bump to 0.9.0
  * update async_trait: 0.1.71 -> 0.1.86
  * Setup log and store dir with systemd (#8241)
  * Upgrade dependencies used by streampager
  * Add process state aggregate in summary view in 'below'
  * third-party: enable signal feature in crate `nix`
  * Revert D68497030: Upgrade clap* packages
  * Upgrade clap* packages
  * update "bytes" crate: 1.6.0 -> 1.9.0
  * Fix non-determinism in test
  * add internal manpage
  * Update `libbpf-rs` & `libbpf-cargo` to `0.25.0-beta.1`
  * upgrade anyhow: 1.0.86 -> 1.0.95
  * update itertools: 13.0.0 -> 14.0.0
  * remove scuba commands from man page
  * Add a man page for below
  * upgrade nix to 0.29.0
  * Update thiserror from 1.0.69 to 2.0.3
  * Store slabinfo in vec
  * Fix procfs read
  * upgrade nix to 0.26.4
  * update tar from 0.4.42 to 0.4.43
  * update serde 1.0.203->1.0.214, serde_json 1.0.125->1.0.132
  * update and improve cgroup memory aggregation
  * Vendor ractor 0.12.4 and upgrade tokio to 1.41.0
  * Update `libbpf-rs` & `libbpf-cargo` to `0.24.6`
  * Removed vulnerable mio 0.7.7 by upgrading crates to use mio 0.8+
  * update itertools 0.12.1 -> 0.13.0
  * update itertools 0.11.0 -> 0.12.1
  * Update tar from 0.4.40 to 0.4.42
  * Upgrade clap, clap_complete
  * Upgrade serde_json to 1.0.125
  * Update gitoxide to version with lenient tag parsing
  * switch cgroup memoryevents to be rates for below
  * Fix io.stat parsing
  * collapse immediate children on '='
  * Enable `futures` feature on `indicatif`
  * Upgrade bitflags
  * Bump anyhow to 1.0.86
  * Update `libbpf-rs` & `libbpf-cargo` to `0.24.4`
  * Update `libbpf-rs` & `libbpf-cargo` to 0.24.2
  * Update `libbpf-rs` & `libbpf-cargo` to 0.24.2
  * Update `libbpf-rs` & `libbpf-cargo` to 0.24.1
  * Bump clap{,_complete} to 4.5.11
  * Add init guard
  * Change `flows_per_sec` to flows in `tc` module (#8237)
  * clippy lints (#8236)
  * ethtool: clippy lints + license header
  * config: clippy lints
  * btrfs: clippy lints
  * dump: clippy lints
  * common: clippy lints
  * tc: clippy lints + license header
  * view: clippy lints
  * store: clippy lints
  * render: clippy lints
  * gpu_stats: clippy lints
  * model: clippy lints
  * procfs: clippy lints
  * below_derive: clippy lints
  * below_derive: Make EnumToString implement Format instead of ToString
  * Update `libbpf-rs` & `libbpf-cargo` to `0.23.3`
  * Support resolved macros in named deps in autocargo
  * Dodge collisions with _arguments options
  * below: cmdline: Avoid MPSC queue overhead in priority inversion avoidance
  * below: exitstat: Read MM_{ANON,SHMEM}PAGES per-CPU counters for v6.2
  * below: treewide: .split_whitespace() -> .split_ascii_whitespace()
  * Update clap to 4.5.6 and clap_complete to 4.5.4
  * below: main: Log panics to all log sources
  * below: cgroupfs: Provide buffer for CgroupReader lifetime
  * below: procfs: Extract internal buffer handling into a function
  * below: procfs: Use RefCell for internal file buffer
  * below: read_all_pids: Use byte iteration for pid walking
  * below: ioctl: Ensure ioctl(SIOCETHTOOL) compat across libc implementations
  * below: uptime: Reduce syscall overhead with clock_gettime(CLOCK_BOOTTIME)
  * below: pid_cgroup: Avoid intermediate vector alloc
  * below: stat: Avoid intermediate split vector allocation
  * below: procfs: Reinterpret internal buffer as &str without realloc
  * below: procfs: Amortise file buffer allocation
  * below: pidwalk: Avoid statx() and use DT_* where possible
  * below: cgroupfs: Parse KV format without vector alloc
  * below: cgroupfs: Parse eq-based format without vector alloc
  * below: cmdline: Avoid perverse std::io::Read::read_to_end heuristics
  * Fix system model cpu irq
  * ksm view
  * ksm render model and config
  * ksm reading capability
  * Update `libbpf-rs` & `libbpf-cargo` to `0.23.1`
  * set timezone in test before dumping timestamp
  * update authors
  * fix description
  * Record memory.events.local
  * Fix open source build
  * Support summary view extra rows
  * Make viewrc part of view state
  * Rename core_view to system_view
  * Rename system_view to summary_view
  * Add sub-module for reading `tc` stats (#8210)
  * update 'clap-4' crate to 4.5.4
  * Add local mm_rss_stat definition
  * Update tokio: 1.36.0 -> 1.37.0
  * QueriableContainer
  * [below[ Add below_derive::queriable_derives
  * Fix integration test
  * third-party/rust: Bump bytes 1.1 -> 1.6.0
* Fri Jan 10 2025 Alessio Biancalana <alessio.biancalana@suse.com>
- Add %%pre hook
- Get rid of unneeded attack surface
- Comply with logrotate config naming convention
* Tue Dec 31 2024 Alessio Biancalana <alessio.biancalana@suse.com>
- Add initial below package
